summaryrefslogtreecommitdiffstats
path: root/kcontrol/kcontrol/modulemenu.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kcontrol/kcontrol/modulemenu.cpp')
-rw-r--r--kcontrol/kcontrol/modulemenu.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kcontrol/kcontrol/modulemenu.cpp b/kcontrol/kcontrol/modulemenu.cpp
index ad60eda5a..6ab262508 100644
--- a/kcontrol/kcontrol/modulemenu.cpp
+++ b/kcontrol/kcontrol/modulemenu.cpp
@@ -68,9 +68,9 @@ void ModuleMenu::fill(KPopupMenu *parentMenu, const TQString &parentPath)
connect(menu, TQT_SIGNAL(activated(int)), this, TQT_SLOT(moduleSelected(int)));
// Item names may contain ampersands. To avoid them being converted to
// accelators, replace them with two ampersands.
TQString name = group->caption();
- name.replace("&", "&&");
+ name.tqreplace("&", "&&");
parentMenu->insertItem(KGlobal::iconLoader()->loadIcon(group->icon(), KIcon::Desktop, KIcon::SizeSmall)
, name, menu);
@@ -83,9 +83,9 @@ void ModuleMenu::fill(KPopupMenu *parentMenu, const TQString &parentPath)
for (module=moduleList.first(); module != 0; module=moduleList.next())
{
// Item names may contain ampersands. To avoid them being converted to
// accelators, replace them with two ampersands.
TQString name = module->moduleName();
- name.replace("&", "&&");
+ name.tqreplace("&", "&&");
int realid = parentMenu->insertItem(KGlobal::iconLoader()->loadIcon(module->icon(), KIcon::Desktop, KIcon::SizeSmall)
, name, id);
@@ -68,9 +68,9 @@ void ModuleMenu::fill(KPopupMenu *parentMenu, const TQString &parentPath)
connect(menu, TQT_SIGNAL(activated(int)), this, TQT_SLOT(moduleSelected(int)));
// Item names may contain ampersands. To avoid them being converted to
- // accelators, replace them with two ampersands.
+ // accelators, tqreplace them with two ampersands.
TQString name = group->caption();
@@ -83,9 +83,9 @@ void ModuleMenu::fill(KPopupMenu *parentMenu, const TQString &parentPath)
{
// Item names may contain ampersands. To avoid them being converted to
- // accelators, replace them with two ampersands.
+ // accelators, tqreplace them with two ampersands.
TQString name = module->moduleName();